@@ -1,28 +1,16 @@
 ## plot_demo.R | unikn
-## spds | uni.kn | 2022 09 20
+## spds | uni.kn | 2022 11 04
 ## ---------------------------
 
 ## Demo functions for color palettes.
 
-# (A) Common components: ------
+# (A) Common components: See file plot_util.R --------
 
-# set_seed(): ---- 
+# (B) Individual functions: --------
 
-set_seed <- function(seed){
-  
-  if (is.null(seed) || is.na(seed)){
-    seed <- sample(1:999, size = 1)  # randomize
-  }
-  
-  set.seed(seed)
-  
-} # set_seed().
+# plot_bar: A bar plot ------ 
 
-
-
-# (B) Individual functions: -----
-
-# plot_bar: A bar plot ---- 
+# Note: ... is passed to barplot().
 
 plot_bar <- function(pal, col_par = NULL, alpha = 1, 
                      n = 5,  # scaling: number of categories (for each color) 
@@ -31,20 +19,21 @@ plot_bar <- function(pal, col_par = NULL, alpha = 1,
                      main = NULL,
                      sub = NULL, 
                      pal_name = NULL, 
-                     seed = NULL){
+                     seed = NULL,
+                     ...
+){
   
   # Prepare: ---- 
   
   # Parameters currently fixed:
-  # axes <- FALSE
-  # cex?
   
   # colors:
   col_pal <- usecol(pal = pal, alpha = alpha)
   n_col <- length(col_pal)
   
   # seed:
-  set_seed(seed)
+  seed <- set_seed(seed)
+  # print(seed)  # replicability / 4debugging
   
   # par: ---- 
   
@@ -54,7 +43,7 @@ plot_bar <- function(pal, col_par = NULL, alpha = 1,
     col_par <- grDevices::grey(2/3, alpha = 1)  # NA hides border/subtitle
   }
   
-  if (alpha < 1){
+  if ((is.na(alpha) == FALSE) && (alpha < 1)){
     col_par <- usecol(col_par, alpha = alpha)  # apply alpha
   }
   
@@ -126,10 +115,11 @@ plot_bar <- function(pal, col_par = NULL, alpha = 1,
   barplot(mx, 
           beside = beside, horiz = horiz, 
           col = col_pal, border = col_par, density = NA,
-          # col.axis = col_par, col.lab = col_par, 
+          axes = plot_axes(col_par), # col.axis = col_par,
           # names.arg = names(mx), 
           # legend = TRUE, xlim = c(0, x_max),  # if (legend)
-          main = main
+          main = main,
+          ...
   )
   
   # # Background rectangle (if axes == FALSE):
@@ -152,19 +142,177 @@ plot_bar <- function(pal, col_par = NULL, alpha = 1,
   
   on.exit(par(opar))
   
+  # print(mx) # as side effect / 4debugging
+  
   return(invisible(mx))
   
 } # plot_bar().
 
 # # Check:
-# plot_bar(c("firebrick", "gold", "steelblue", "forestgreen"), col_par = "grey")
+# plot_bar(c("firebrick", "gold", "steelblue", "forestgreen"), col_par = "black")
 # plot_bar(c("firebrick", "gold", "steelblue", "forestgreen"),
 #          n = 7, beside = F, horiz = F, as_prop = F, seed = 7)
 # plot_bar(pal_unikn_pref, n = 4, beside = F, horiz = T, as_prop = T, col_par = NA)
 
 
 
-# plot_polygon: A polygon/mountain range plot ---- 
+# plot_ncurve: Plot overlapping normal curves ------
+
+# Note: ... passed to polygon().
+
+#' @importFrom stats runif 
+#' @importFrom stats dnorm
+
+plot_ncurve <- function(pal, col_par = NULL, alpha = 2/3, 
+                        n = 100,  # scaling: x_max value 
+                        # args with defaults:
+                        main = NULL,
+                        sub = NULL, 
+                        pal_name = NULL, 
+                        seed = NULL, 
+                        ...
+){
+  
+  # Prepare: ---- 
+  
+  # Parameters currently fixed:
+  
+  # Colors:
+  col_pal <- usecol(pal = pal, alpha = alpha)
+  n_col <- length(col_pal)
+  
+  # Seed:
+  set_seed(seed)
+  
+  
+  # par: ---- 
+  
+  opar <- par(no.readonly = TRUE)
+  
+  if (is.null(col_par)){ # set default:
+    col_par <- grDevices::grey(2/3, alpha = 1)  # NA hides border/subtitle
+  }
+  
+  if ((is.na(alpha) == FALSE) && (alpha < 1)){
+    col_par <- usecol(col_par, alpha = alpha)  # apply alpha
+  }
+  
+  par(col = col_par)
+  
+  par(mar = c(4, 3, 3, 2) + 0.1) # default: c(5, 4, 4, 2) + 0.1
+  
+  
+  # Create data: ---- 
+  
+  # Dimensions: 
+  x_min <- 0
+  x_max <- n
+  
+  delta_x <- abs(x_max - x_min)  
+  n_steps <- max(delta_x + 1, 11)
+  
+  # Curve parameters:
+  mn <- runif(n_col, min = x_min + n/10, max = x_max - n/10)
+  sd <- runif(n_col, min = n/10, max = n * 3/10)
+  
+  # Hack: 1st curve has medium mean and lowest sd/maximum height:
+  mn[1] <- runif(1, min = (x_min + n * .20), max = (x_max - n * .20))
+  sd[1] <- n/10  # min sd/max height
+  
+  mn <- round(mn, digits = 2)
+  sd <- round(sd, digits = 2)  
+  
+  df <- data.frame(mn = mn,
+                   sd = sd)
+  
+  # Plot: ----
+  
+  # Color:
+  col_brd <- col_par 
+  
+  # Loop: 1 curve per n_col:
+  for (i in 1:n_col){ 
+    
+    # Polygon boundaries:
+    x_upper <- seq(from = x_min, to = x_max, length.out = n_steps)
+    x_lower <- rev(x_upper)
+    y_upper <- dnorm(x_upper, mean = mn[i], sd = sd[i])
+    y_lower <- rep(0, length(x_lower))
+    
+    xxp <- c(x_lower, x_upper)
+    yyp <- c(y_lower, y_upper)
+    
+    if (i == 1) { # first curve: 
+      
+      # Initialize empty plot:
+      plot(0, type = "n", 
+           xlim = c(min(xxp), max(xxp)), ylim = c(min(yyp), max(yyp)), 
+           axes = plot_axes(col_par), # col.axis = col_par,
+           xlab = NA, ylab = NA,      # cex.axis = cex_lbl
+           main = NA
+      )
+      
+      # Axes:
+      # if (axes == FALSE) {
+      #   
+      #   x_seq <- seq(x_min, x_max, length.out = 11)
+      #   x_lbl <- paste0(x_seq) 
+      #   y_seq <- seq(min(yyp), max(yyp), length.out = 5)
+      #   y_lbl <- paste0(round(y_seq, 2))
+      #   
+      #   axis(side = 1, at = x_seq, labels = x_lbl)  # x at bottom
+      #   axis(side = 2, at = y_seq, labels = y_lbl)  # y at left
+      #   
+      # }
+      
+      # Titles:
+      if (is.null(main)){ # default title:
+        plot_type <- "curve"  # "normal curve"
+        main <- paste("A", plot_type, "plot")
+      }
+      
+      title(main = main)
+      
+      if (is.null(sub)){ # default subtitle:
+        if (is.null(pal_name)){
+          pal_name <- deparse(substitute(pal))  # get object name (of input pal)
+        }
+        sub <- paste("Illustrating color palette", pal_name)
+      }
+      mtext(sub, side = 1, line = 2, adj = 1, cex = .95)
+      
+      
+      # Draw first polygon:
+      polygon(xxp, yyp, col = col_pal[i], border = col_brd, ...)  
+      
+    } else {
+      
+      # Drow polygons 2 to n_col:
+      polygon(xxp, yyp, col = col_pal[i], border = col_brd, ...) 
+      
+    }
+    
+  } # for i.
+  
+  
+  # Output: ---- 
+  
+  on.exit(par(opar))
+  
+  # print(df) # as side effect / 4debugging
+  
+  return(invisible(df))
+  
+} # plot_ncurve().
+
+# # Check: 
+# plot_ncurve(c("steelblue", "gold", "forestgreen", "firebrick"), alpha = 2/3)
+# plot_ncurve(pal_unikn_pref, col_par = NA, alpha = 1/3)
+
+
+# plot_polygon: A polygon/mountain range plot ------ 
+
+# Note: ... passed to polygon().
 
 plot_polygon <- function(pal, col_par = NULL, alpha = 1, 
                          n = 100,  # scaling: x-range
@@ -172,12 +320,13 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
                          main = NULL,
                          sub = NULL, 
                          pal_name = NULL, 
-                         seed = NULL){
+                         seed = NULL,
+                         ...
+){
   
   # Prepare: ---- 
   
   # Parameters currently fixed:
-  axes <- FALSE
   
   # colors:
   col_pal <- usecol(pal = pal, alpha = alpha)
@@ -190,8 +339,8 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
   }
   
   # seed:
-  set_seed(seed)
-  
+  seed <- set_seed(seed)
+  # print(seed)  # replicability / 4debugging
   
   # par: ---- 
   
@@ -201,7 +350,7 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
     col_par <- grDevices::grey(2/3, alpha = 1)  # NA hides border/subtitle
   }
   
-  if ( (alpha < 1) & (is.na(col_par) == FALSE) ){
+  if ((is.na(alpha) == FALSE) && (alpha < 1)){
     col_par <- usecol(col_par, alpha = alpha)  # apply alpha
   }
   
@@ -230,27 +379,22 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
   
   col_brd <- col_par 
   
-  # Prepare plot:
-  # plot(x = 0, type = "n", 
-  #      xlim = c(x_min, x_max), 
-  #      ylim = c(y_min, y_max), 
-  #      xlab = "X-value", ylab = "Y-value", 
-  #      main = "A polygon plot")
-  
-  plot(0, type = "n",     # (a) empty plot
-       # x = dt, col = col_pal,  # (b) generic plot
+  # Initialize empty plot:
+  plot(0, type = "n",
        xlim = c(x_min, x_max), ylim = c(y_min, y_max),
-       main = NA, xlab = NA, ylab = NA
+       axes = plot_axes(col_par), # col.axis = col_par,
+       xlab = NA, ylab = NA,
+       main = NA
   )
   
   # Create n_col - 1 non-overlapping lines in range:
   for (i in 1:(n_col - 1)){
     
     # Maximum variability:
-    if (n_col < 5){
+    if (n_col < 10){
       max_var <- 1/5  # constant
     } else {
-      max_var <- 2/i  # mountain range (rugged front, smoother back) 
+      max_var <- 3/(i * 2)  # mountain range (rugged front, smoother back) 
     }
     
     y <- i + round(c(0, cumsum(runif(N, -max_var, +max_var))), 2)
@@ -265,7 +409,7 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
     df[paste0("y_", i)] <- y  # record current y value
     
     y_plus <- c(y, rev(y_0))  # prepare for polygon
-    polygon(x = x_plus, y = y_plus, col = col_pal[i], border = col_brd) 
+    polygon(x = x_plus, y = y_plus, col = col_pal[i], border = col_brd, ...) 
     
     y_0 <- y  # remember previous/last/lower y-values
     
@@ -278,7 +422,7 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
   df[paste0("y_", n_col)] <- y
   
   y_plus <- c(y, rev(y_0))  # prepare for polygon
-  polygon(x = x_plus, y = y_plus, col = col_pal[n_col], border = col_brd)
+  polygon(x = x_plus, y = y_plus, col = col_pal[n_col], border = col_brd, ...)
   
   
   # # Background rectangle (if axes == FALSE):
@@ -308,6 +452,8 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
   
   on.exit(par(opar))
   
+  # print(df) # as side effect / 4debugging
+  
   return(invisible(df))
   
 } # plot_polygon().
@@ -320,7 +466,9 @@ plot_polygon <- function(pal, col_par = NULL, alpha = 1,
 # head(x)
 
 
-# plot_table: An area/mosaic plot ---- 
+# plot_table: An area/mosaic plot ------ 
+
+# Note: ... passed to plot().
 
 plot_table <- function(pal, col_par = NULL, alpha = 1, 
                        n = 20,  # scaling: instances per dimension is n * n_col
@@ -328,19 +476,27 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
                        main = NULL,
                        sub = NULL, 
                        pal_name = NULL, 
-                       seed = NULL){
+                       seed = NULL,
+                       ...
+){
   
   # Prepare: ---- 
   
   # Parameters currently fixed:
-  axes <- FALSE
   
-  # colors:
+  # Colors:
   col_pal <- usecol(pal = pal, alpha = alpha)
   n_col <- length(col_pal)
   
+  if (n_col < 2){ # special case: 
+    col_pal <- c(col_pal, par("bg"))  # add bg color of device 
+    # col_pal <- c(par("col"), col_pal, par("bg"))  # add fg and bg color of device 
+    n_col   <- length(col_pal)
+  }
+  
   # seed:
-  set_seed(seed)
+  seed <- set_seed(seed)
+  # print(seed)  # replicability / 4debugging
   
   
   # par: ---- 
@@ -351,7 +507,7 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
     col_par <- grDevices::grey(2/3, alpha = 1)  # NA hides border/subtitle
   }
   
-  if (alpha < 1){
+  if ((is.na(alpha) == FALSE) && (alpha < 1)){
     col_par <- usecol(col_par, alpha = alpha)  # apply alpha
   }
   
@@ -377,11 +533,14 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
   y_min <- 0
   y_max <- 1
   
+  # Generic plot (mosaic plot): 
   plot(#0, 0, type = "n",   # (a) empty plot
     x = tb, col = col_pal,  # (b) generic plot
     border = col_par, 
-    main = NA, xlab = NA, ylab = NA
-  )
+    # axes = plot_axes(col_par), # col.axis = col_par,
+    xlab = NA, ylab = NA,
+    main = NA,
+    ...)
   
   # Background rectangle (if axes == FALSE):
   bwd <- .06  # border width
@@ -394,6 +553,7 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
     plot_type <- "mosaic" # "table"
     main <- paste("A", plot_type, "plot")
   }
+  
   title(main = main)
   
   if (is.null(sub)){ # default subtitle:
@@ -409,6 +569,8 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
   
   on.exit(par(opar))
   
+  # print(tb) # as side effect / 4debugging
+  
   return(invisible(tb))
   
 } # plot_table().
@@ -420,23 +582,26 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
 
 
 
-# plot_scatter: A plot of points ---- 
+# plot_scatter: A plot of points ------ 
+
+# Note: ... passed to plot().
 
 #' @importFrom stats runif 
 
-plot_scatter <- function(pal, col_par = NULL, alpha = 1, 
+plot_scatter <- function(pal, col_par = NULL, alpha = 2/3, 
                          n = 500,     # scaling: number of points
                          cex = NULL,  # type-specific parameter(s): point size
                          # args with defaults:
                          main = NULL,
                          sub = NULL, 
                          pal_name = NULL, 
-                         seed = NULL){
+                         seed = NULL,
+                         ...
+){
   
   # Prepare: ---- 
   
   # Parameters currently fixed:
-  axes <- TRUE
   
   # Defaults:
   if (is.null(cex)){
@@ -449,7 +614,8 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
   n_col <- length(col_pal)
   
   # seed:
-  set_seed(seed)
+  seed <- set_seed(seed)
+  # print(seed)  # replicability / 4debugging
   
   # par: ---- 
   
@@ -459,7 +625,7 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
     col_par <- grDevices::grey(2/3, alpha = 1)  # NA hides border/subtitle
   }
   
-  if (alpha < 1){
+  if ((is.na(alpha) == FALSE) && (alpha < 1)){
     col_par <- usecol(col_par, alpha = alpha)  # apply alpha
   }
   
@@ -472,9 +638,9 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
   
   # n <- 500
   
-  x_min <- 1
+  x_min <- 0
   x_max <- n_col
-  y_min <- 1
+  y_min <- 0
   y_max <- n_col
   
   x <- round(stats::runif(n, min = x_min, max = x_max), 2)
@@ -485,10 +651,13 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
   # Main plot: ---- 
   
   plot(#0, 0, type = "n",  # (a) empty plot
-    x = df$x, y = df$y, type = "p", pch = 20, col = col_pal, cex = cex, # (b) generic plot
+    x = df$x, y = df$y, type = "p", pch = 21, bg = col_pal, col = col_par, cex = cex, # (b) generic plot
     xlim = c(x_min, x_max), ylim = c(y_min, y_max),  
-    axes = axes, col.axis = col_par,  
-    xlab = NA, ylab = NA)
+    axes = plot_axes(col_par), # col.axis = col_par,
+    xlab = NA, ylab = NA,
+    main = NA,
+    ...
+  )
   
   # # Background rectangle (if axes == FALSE):
   # bwd <- .08  # border width
@@ -519,6 +688,8 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
   
   on.exit(par(opar))
   
+  # print(df) # as side effect / 4debugging
+  
   return(invisible(df))
   
 } # plot_scatter().
@@ -530,9 +701,10 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
 # x
 
 
-# (C) Wrapper function: ------
 
-# demopal: A general function to call specific functions: ---- 
+# (C) Wrapper function: --------
+
+# demopal: A general function to call specific functions: ------ 
 
 #' Demonstrate a color palette.
 #'
@@ -551,10 +723,16 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
 #'   \item \code{main} plot title (on top); 
 #'   \item \code{sub} plot subtitle (on right margin);  
 #'   
-#'   \item \code{seed} A random seed (for reproducible randomness). 
+#'   \item \code{seed} A random seed value (for reproducible randomness). 
 #'   
 #' }
 #' 
+#' The fit between a color palette \code{pal} and plot \code{type} 
+#' depends on the uses of colors in a plot. 
+#' For instance, overlaps of transparent color areas can be evaluated 
+#' with plot \code{type = "curve"} or plot \code{type = "scatter"} 
+#' (and \code{0 < alpha < 1}). 
+#' 
 #' Some functions additionally accept type-specific arguments 
 #' (e.g., \code{beside}, \code{horiz}, and \code{as_prop}, for plot \code{type = "bar"}, 
 #' and \code{cex} for plot \code{type = "scatter"}). 
@@ -567,8 +745,10 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
 #' @param pal A color palette (to be illustrated).
 #' Default: \code{pal = pal_unikn}. 
 #' 
-#' @param type The type of plot to be used (as character or integer index). 
-#' Permissible types are \code{"bar"}, \code{"mosaic"}, \code{"scatter"} (or 1 to 3).
+#' @param type The type of plot to be used (as character string or integer value). 
+#' Permissible types are 
+#' \code{"bar"}, \code{"curve"}, \code{"mosaic"}, \code{"polygon"}, or \code{"scatter"} 
+#' (or an integer value from 1 to 5, respectively).
 #' 
 #' @param pal_name A name for the input color palette \code{pal} (shown on bottom-right margin). 
 #' Default: \code{pal_name = NULL} (deparsing to input name).
@@ -592,6 +772,7 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
 #' 
 #' @aliases democol
 #' @aliases demofun
+#' @aliases demoplot
 #' 
 #' @seealso 
 #' \code{\link{seepal}} for plotting color palettes;  
@@ -608,13 +789,40 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 1,
 demopal <- function(pal = pal_unikn, type = NA, pal_name = NULL, ...){
   
   # Prepare: ---- 
-  plot_types <- c("bar", "mosaic", "polygon", "scatter")  # as constant
   
-  # type: 
+  if (all(is.na(pal))) { return(NA) }  # handle pal = NA case
+  
+  plot_types <- c("bar", "curve", "mosaic", "polygon", "scatter")  # as constant
+  
+  # type:
   if (is.character(type)){
     
-    if (type %in% plot_types){
-      type <- which(type == plot_types)
+    # Increase robustness:
+    type_1_3 <- substr(tolower(type), 1, 3)
+    ptyp_1_3 <- substr(plot_types, 1, 3)
+    
+    # Alternative names: 
+    
+    # "mosaic":
+    if (type_1_3 == "are") { type_1_3 <- "mos" }  # "area"  
+    if (type_1_3 == "tab") { type_1_3 <- "mos" }  # "table"
+    
+    # "polygon":
+    if (type_1_3 == "mou") { type_1_3 <- "pol" }  # "mountain"
+    if (type_1_3 == "rid") { type_1_3 <- "pol" }  # "ridge"
+    
+    # "curve":
+    if (type_1_3 == "dis") { type_1_3 <- "cur" }  # "distribution"
+    if (type_1_3 == "his") { type_1_3 <- "cur" }  # "histogram"
+    if (type_1_3 == "ncu") { type_1_3 <- "cur" }  # "ncurve"
+    if (type_1_3 == "nor") { type_1_3 <- "cur" }  # "normal"
+    if (type_1_3 == "wav") { type_1_3 <- "cur" }  # "wave"
+    
+    # "scatter":
+    if (type_1_3 == "poi") { type_1_3 <- "sca" }  # "point"
+    
+    if (type_1_3 %in% ptyp_1_3){
+      type <- which(type_1_3 == ptyp_1_3)  # numeric
     } else {
       plot_types_q <- add_quotes(plot_types)
       message(paste("The plot type", add_quotes(type), "is not in", plot_types_q))
@@ -635,11 +843,13 @@ demopal <- function(pal = pal_unikn, type = NA, pal_name = NULL, ...){
   switch(type,
          # 1: bar: 
          plot_bar(pal = pal, pal_name = pal_name, ...), 
-         # 2: mosaic/table:
+         # 2. curve/ncurve:
+         plot_ncurve(pal = pal, pal_name = pal_name, ...), 
+         # 3: mosaic/table:
          plot_table(pal = pal, pal_name = pal_name, ...), 
-         # 3: polygon:
+         # 4: polygon:
          plot_polygon(pal = pal, pal_name = pal_name, ...), 
-         # 4: scatter/point:
+         # 5: scatter/point:
          plot_scatter(pal = pal, pal_name = pal_name, ...), 
          # else:
          plot_polygon(pal = pal, pal_name = pal_name, ...)
@@ -650,7 +860,7 @@ demopal <- function(pal = pal_unikn, type = NA, pal_name = NULL, ...){
 } # demopal(). 
 
 
-## ToDo: ------
+## ToDo: --------
 
 # - Add more plot types.
 
